==> mzanalytics_mybmw-0.4.1.tar.gz: lib/mzanalytics_checkout.dart <==
import 'dart:async';

import 'package:mzanalytics_mybmw/mzanalytics_log.dart';

class MzanalyticsCheckOut {
  ///正则判断表
  static RegExp number = RegExp(r"\d$");

  ///方法列表
  static Future<bool> appidCheck(var appid) async {
    try {
      if ((appid is String) == false) {
        MzanalyticsLog.p('appid 必须为String类型');
        return false;
      }

      if (number.hasMatch(appid) == false) {
        MzanalyticsLog.p('appid  必须为数字');
        return false;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> trackPageViewCheck(var p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if ((p['dt'] is String) == false) {
        MzanalyticsLog.p('dt 必须为String类型');
        return false;
      }

      if (p['CustomDimMetrics'] is Map) {
        bool ret = await cdmCheck(p['CustomDimMetrics']);

        return ret;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> trackEventCheck(var p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if (((p['ec'] is String) == false ||
              ((p['ec'] is String) == true) && p['ec'].length == 0) &&
          ((p['ea'] is String) == false ||
              ((p['ea'] is String) == true) && p['ea'].length == 0) &&
          ((p['el'] is String) == false ||
              ((p['el'] is String) == true) && p['el'].length == 0)) {
        MzanalyticsLog.p('请输入事件分类、事件动作、事件标签中的任意一个参数');
        return false;
      }
      if (p['ev'] != null) {
        if ((p['ev'] is String) == false) {
          MzanalyticsLog.p('ev 必须为String类型');
          return false;
        }
        if (!number.hasMatch(p['ev'])) {
          MzanalyticsLog.p('ev  必须为数字');
          return false;
        }
      }

      if (p['CustomDimMetrics'] is Map) {
        bool ret = await cdmCheck(p['CustomDimMetrics']);
        return ret;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> trackSiteCustomEventCheck(var p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if ((p['CustomEvent'] is Map) == false) {
        MzanalyticsLog.p('CustomEvent 必须为Map类型');
        return false;
      }

      bool caRet = await caCheck(p['CustomEvent']);

      if (caRet == false) {
        return false;
      }

      if (p['CustomDimMetrics'] is Map) {
        bool ret = await cdmCheck(p['CustomDimMetrics']);
        return ret;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  //自定义指标判断
  static Future<bool> caCheck(Map p) async {
    try {
      if ((p['caid'] is String) == false) {
        MzanalyticsLog.p('caid 必须为String类型');
        return false;
      }
      if (!number.hasMatch(p['caid'])) {
        MzanalyticsLog.p('caid  必须为数字');
        return false;
      }
      for (var i = 1; i < 21; i++) {
        String calK = 'cal' + i.toString();
        String cavK = 'cav' + i.toString();
        if (p.containsKey(calK)) {
          if ((p[calK] is String) == false) {
            MzanalyticsLog.p(calK + ' 必须为String类型');
            return false;
          }
        }
        if (p.containsKey(cavK)) {
          if ((p[cavK] is String) == false) {
            MzanalyticsLog.p(cavK + ' 必须为String类型');
            return false;
          }
          if (!number.hasMatch(p[cavK])) {
            MzanalyticsLog.p(cavK + '  必须为数字');
            return false;
          }
        }
      }

      return true;
    } catch (e) {
      return false;
    }
  }

//通用的高级维度判断
  static Future<bool> cdmCheck(Map p) async {
    try {
      for (var i = 1; i < 26; i++) {
        String cdK = 'cd' + i.toString();
        String cmK = 'cm' + i.toString();
        if (p.containsKey(cdK)) {
          if ((p[cdK] is String) == false) {
            MzanalyticsLog.p(cdK + ' 必须为String类型');
            return false;
          }
        }
        if (p.containsKey(cmK)) {
          if ((p[cmK] is String) == false) {
            MzanalyticsLog.p(cmK + ' 必须为String类型');
            return false;
          }
          if (!number.hasMatch(p[cmK])) {
            MzanalyticsLog.p(cmK + '  必须为数字');
            return false;
          }
        }
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> setCdCheck(var cd) async {
    try {
      if ((cd is String) == false) {
        MzanalyticsLog.p('cd 的 Key 与 Value 必须为String类型');
        return false;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> setCmCheck(var cm) async {
    try {
      if ((cm is String) == false) {
        MzanalyticsLog.p('cm 必须为String类型');
        return false;
      }
      if (!number.hasMatch(cm)) {
        MzanalyticsLog.p('cm  必须为数字');
        return false;
      }

      return true;
    } catch (e) {
      return false;
    }
  }
}

==> mzanalytics_mybmw-0.8.1-dev.3.tar.gz: lib/mzanalytics_checkout.dart <==
import 'dart:async';

import 'package:mzanalytics_mybmw/mzanalytics_log.dart';

class MzanalyticsCheckOut {
  ///正则判断表
  static RegExp number = RegExp(r"\d$");

  ///方法列表
  static Future<bool> appidCheck(var appid) async {
    try {
      if ((appid is String) == false) {
        MzanalyticsLog.p('appid 必须为String类型');
        return false;
      }

      if (number.hasMatch(appid) == false) {
        MzanalyticsLog.p('appid  必须为数字');
        return false;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> trackPageViewCheck(var p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if ((p['dt'] is String) == false) {
        MzanalyticsLog.p('dt 必须为String类型');
        return false;
      }

      if (p['CustomDimMetrics'] is Map) {
        bool ret = await cdmCheck(p['CustomDimMetrics']);

        return ret;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> trackEventCheck(Map p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if (((p['ec'] is String) == false ||
              ((p['ec'] is String) == true) && p['ec'].length == 0) &&
          ((p['ea'] is String) == false ||
              ((p['ea'] is String) == true) && p['ea'].length == 0) &&
          ((p['el'] is String) == false ||
              ((p['el'] is String) == true) && p['el'].length == 0)) {
        MzanalyticsLog.p('请输入事件分类、事件动作、事件标签中的任意一个参数');
        return false;
      }
      if (p.containsKey('ec')) {
        if ((p['ec'] is String) == false) {
          MzanalyticsLog.p('ec 必须为String类型');
          return false;
        }
      }
      if (p.containsKey('ea')) {
        if ((p['ea'] is String) == false) {
          MzanalyticsLog.p('ea 必须为String类型');
          return false;
        }
      }
      if (p.containsKey('el')) {
        if ((p['el'] is String) == false) {
          MzanalyticsLog.p('el 必须为String类型');
          return false;
        }
      }
      if (p.containsKey('ev')) {
        if ((p['ev'] is String) == false) {
          MzanalyticsLog.p('ev 必须为String类型');
          return false;
        }

        if (!number.hasMatch(p['ev'])) {
          MzanalyticsLog.p('ev  必须为数字');
          return false;
        }
      }

      if (p['CustomDimMetrics'] is Map) {
        bool ret = await cdmCheck(p['CustomDimMetrics']);
        return ret;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> trackSiteCustomEventCheck(var p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if ((p['CustomEvent'] is Map) == false) {
        MzanalyticsLog.p('CustomEvent 必须为Map类型');
        return false;
      }

      bool caRet = await caCheck(p['CustomEvent']);

      if (caRet == false) {
        return false;
      }

      if (p['CustomDimMetrics'] is Map) {
        bool ret = await cdmCheck(p['CustomDimMetrics']);
        return ret;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  //自定义指标判断
  static Future<bool> caCheck(Map p) async {
    try {
      if ((p['caid'] is String) == false) {
        MzanalyticsLog.p('caid 必须为String类型');
        return false;
      }
      if (!number.hasMatch(p['caid'])) {
        MzanalyticsLog.p('caid  必须为数字');
        return false;
      }
      for (var i = 1; i < 21; i++) {
        String calK = 'cal' + i.toString();
        String cavK = 'cav' + i.toString();
        if (p.containsKey(calK)) {
          if ((p[calK] is String) == false) {
            MzanalyticsLog.p(calK + ' 必须为String类型');
            return false;
          }
        }
        if (p.containsKey(cavK)) {
          if ((p[cavK] is String) == false) {
            MzanalyticsLog.p(cavK + ' 必须为String类型');
            return false;
          }
          if (!number.hasMatch(p[cavK])) {
            MzanalyticsLog.p(cavK + '  必须为数字');
            return false;
          }
        }
      }

      return true;
    } catch (e) {
      return false;
    }
  }

//通用的高级维度判断
  static Future<bool> cdmCheck(Map p) async {
    try {
      for (var i = 1; i < 26; i++) {
        String cdK = 'cd' + i.toString();
        String cmK = 'cm' + i.toString();
        if (p.containsKey(cdK)) {
          if ((p[cdK] is String) == false) {
            MzanalyticsLog.p(cdK + ' 必须为String类型');
            return false;
          }
        }
        if (p.containsKey(cmK)) {
          if ((p[cmK] is String) == false) {
            MzanalyticsLog.p(cmK + ' 必须为String类型');
            return false;
          }
          if (!number.hasMatch(p[cmK])) {
            MzanalyticsLog.p(cmK + '  必须为数字');
            return false;
          }
        }
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> setCdCheck(var cd) async {
    try {
      if ((cd is String) == false) {
        MzanalyticsLog.p('cd 的 Key 与 Value 必须为String类型');
        return false;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  static Future<bool> setCmCheck(var cm) async {
    try {
      if ((cm is String) == false) {
        MzanalyticsLog.p('cm 必须为String类型');
        return false;
      }
      if (!number.hasMatch(cm)) {
        MzanalyticsLog.p('cm  必须为数字');
        return false;
      }

      return true;
    } catch (e) {
      return false;
    }
  }

  ///exception校验
  // ignore: missing_return
  static Future<bool> exceptionCheck(Map p) async {
    try {
      if ((p is Map) == false) {
        MzanalyticsLog.p('传入参数必须为Map类型');
        return false;
      }

      if (((p['name'] is String) == false ||
          ((p['name'] is String) == true) && p['name'].length == 0)) {
        MzanalyticsLog.p('请输入异常名称name');
        return false;
      }
      if (((p['reason'] is String) == false ||
          ((p['reason'] is String) == true) && p['reason'].length == 0)) {
        MzanalyticsLog.p('请输入异常原因reason');
        return false;
      }
      if (((p['stack'] is String) == false ||
          ((p['stack'] is String) == true) && p['stack'].length == 0)) {
        MzanalyticsLog.p('请输入异常堆栈stack');
        return false;
      }
      if (((p['customerror'] is String) == false ||
          ((p['customerror'] is String) == true) &&
              p['customerror'].length == 0)) {
        MzanalyticsLog.p('请输入异常类型customerror');
        return false;
      }
      return true;
    } catch (e) {
      return false;
    }
  }
}
